@@ -8,12 +8,11 @@
  *
  ****************************************************************************/
 
-#include "default.h"
+#include "ADM_default.h"
 
 #ifndef NOAVIFMT
 
-#ifndef __WINE_WINDEF_H
-#if !defined( WIN32_CLASH) || !defined(ADM_WIN32)
+#if !defined(__WINE_WINDEF_H) && !defined(_WINDEF_H)
 #define LOBYTE(w)              ((uint8_t)(uint16_t)(w))
 #define HIBYTE(w)              ((uint8_t)((uint16_t)(w) >> 8))
 
@@ -21,7 +20,6 @@
 #define HIWORD(l)              ((uint16_t)((uint32_t)(l) >> 16))
 
 #define MAKELONG(low,high)     ((int32_t)(((uint16_t)(low)) | (((uint32_t)((uint16_t)(high))) << 16)))
-#endif
 
 #endif // __WINE_WINDEF_H
 
