@@ -1,22 +1,5 @@
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <string.h>
-#include <stdio.h>
-
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-
-
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-# include <math.h>
-# include "config.h"
-#include "default.h"
-#include "ADM_toolkit_gtk/ADM_gladeSupport.h"
-#include "ADM_toolkit_gtk/toolkit_gtk.h"
-#include "ADM_toolkit_gtk/toolkit_gtk_include.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_toolkitGtk.h"
+#include "DIA_coreToolkit.h"
 
 static GtkWidget       *create_dialog1 (void);
 static void             updateStatus(void);
@@ -175,7 +158,7 @@ GtkCellRenderer *renderer;
                         case COMMAND_DELETE: 
                                         sel=getSelection(jobs.dialog);
                                         if(sel>=jobs.nb) break;
-                                        if(GUI_Confirmation_HIG(QT_TR_NOOP("Sure!"),QT_TR_NOOP("Delete job"),QT_TR_NOOP("Are you sure you want to delete %s job ?"),GetFileName(jobs.name[sel])))
+                                        if(GUI_Confirmation_HIG(QT_TR_NOOP("Sure!"),QT_TR_NOOP("Delete job"),QT_TR_NOOP("Are you sure you want to delete %s job ?"),ADM_GetFileName(jobs.name[sel])))
                                         {
                                                 jobs.status[sel].status=STATUS_DELETED;
                                         }
@@ -184,7 +167,7 @@ GtkCellRenderer *renderer;
                         
                         default:
                                 printf("Event:%d\n",event); 
-                                GUI_Alert(QT_TR_NOOP("Unknown event"));break;
+                                GUI_Error_HIG("Jobs",QT_TR_NOOP("Unknown event"));break;
                 }
                 
         }
@@ -225,7 +208,7 @@ char *str1,str2[200],str3[200];
         {
                str1 = g_markup_printf_escaped("<span weight=\"heavy\">%s</span>\n" 
                "<span size=\"smaller\" style=\"oblique\">%s</span>"
-                , GetFileName(jobs.name[i]), StringStatus[jobs.status[i].status]);
+                , ADM_GetFileName(jobs.name[i]), StringStatus[jobs.status[i].status]);
 
                 date=&(jobs.status[i].startDate);
                 sprintf(str2,"%02d:%02d:%02d",date->hours,
