@@ -6,22 +6,19 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
 
+#include "ADM_toolkitGtk.h"
 #include <vector>
-#include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
 
-#include "avi_vars.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
-#include "ADM_toolkit/filesel.h"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "DIA_coreToolkit.h"
+#include "DIA_fileSel.h"
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
+#include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_videoNull.h"
-#include "ADM_filter/video_filters.h"
+
 #include "ADM_video/ADM_vidPartial.h"
-#include "ADM_toolkit_gtk/ADM_gladeSupport.h"
-#include "ADM_toolkit_gtk/toolkit_gtk.h"
+#include "avi_vars.h"
 #include "ADM_filter/vidVCD.h"
 //___________________________________________
 typedef enum 
@@ -54,33 +51,41 @@ extern AVDMGenericVideoStream *filterCreateFromTag (VF_FILTERS tag,
 extern const char  *filterGetNameFromTag(VF_FILTERS tag);
 extern uint8_t DIA_filterPreview(const char *captionText, AVDMGenericVideoStream *videoStream, uint32_t frame);
 //___________________________________________
-extern FILTER videofilters[MAX_FILTER];
+extern FILTER videofilters[VF_MAX_FILTER];
 extern uint32_t nb_active_filter;
-extern std::vector <FILTER_ENTRY> allfilters;
+extern std::vector <FilterDescriptor *> allfilters;
+extern std::vector <FilterDescriptor *> filterCategories[VF_MAX];
+
 
 extern ADM_Composer *video_body;
 //___________________________________________
 static gulong row_inserted_id;
 static gulong row_deleted_id;
 
-static void on_treeview0_row_deleted(GtkTreeModel *treemodel, GtkTreePath *arg1, gpointer user_data);
-static void on_treeview0_row_inserted(GtkTreeModel *treemodel, GtkTreePath *arg1, GtkTreeIter *arg2, gpointer user_data);
-static void on_treeview1_size_allocate(GtkWidget *widget, GtkAllocation *allocation, GtkCellRenderer *cell);
+static void on_treeActive_row_deleted(GtkTreeModel *treemodel, GtkTreePath *arg1, gpointer user_data);
+static void on_treeActive_row_inserted(GtkTreeModel *treemodel, GtkTreePath *arg1, GtkTreeIter *arg2, gpointer user_data);
+static void on_tree_size_allocate(GtkWidget *widget, GtkAllocation *allocation, GtkCellRenderer *cell);
 static void on_action (gui_act action);
 static void on_action_double_click (GtkButton * button, gpointer user_data);
 static void on_action_double_click_1 (GtkButton * button, gpointer user_data);
+static void on_action_change_category (GtkWidget *tree, gpointer user_data);
 static void updateFilterList (void);
 static VF_FILTERS getFilterFromSelection (void);
-static void wrapToolButton(GtkWidget * wid, gpointer user_data);
+static void button_clicked(GtkWidget * wid, gpointer user_data);
 //___________________________________________
 #define NB_TREE 9
+const   gint tree_width = 300;
 static  uint32_t max = 0;
-static  GtkWidget *trees[NB_TREE];
+static  GtkListStore *storeCategories;
+static  GtkWidget *treeCategories;
+static  GtkWidget *treeAvailable;
+static  GtkWidget *treeActive;
 static  GtkListStore *stores[NB_TREE];
 static  GtkTreeViewColumn *columns[NB_TREE];
 static  GtkCellRenderer *renderers[NB_TREE];
 static  int startFilter[NB_TREE];
 //___________________________________________
+static GtkWidget *createTree (const gchar *ref);
 static GtkWidget *createFilterDialog (void);
 extern GtkWidget *create_dialog1 (void);
 static GtkWidget *dialog = 0;
@@ -93,10 +98,6 @@ int
 GUI_handleVFilter (void)
 {
 
-#ifndef HAVE_ENCODER
-    return 0;
-}
-#else
     getLastVideoFilter ();	// expand video to full size
 
     // sanity check
@@ -111,10 +112,10 @@ GUI_handleVFilter (void)
         GdkWMDecoration decorations=(GdkWMDecoration)0;
         gtk_widget_realize(dialog);
         gdk_window_set_decorations(dialog->window, (GdkWMDecoration)(GDK_DECOR_ALL | GDK_DECOR_MINIMIZE));
-        GdkScreen* screen = gdk_screen_get_default();
+        /*GdkScreen* screen = gdk_screen_get_default();
         gint width = gdk_screen_get_width(screen);
         if(width>=1024)
-            gtk_window_set_default_size(GTK_WINDOW(dialog), 900, 600);
+            gtk_window_set_default_size(GTK_WINDOW(dialog), 900, 600);*/
         updateFilterList ();
         gtk_register_dialog (dialog);
         //gtk_widget_show (dialog);
@@ -136,25 +137,6 @@ GUI_handleVFilter (void)
     
 }
 
-// gtk_dialog_add_action_widget seems buggy for toolbar button
-// workaround it...
-void
-wrapToolButton(GtkWidget * wid, gpointer user_data)
-{
-        gui_act action;
-#ifdef ARCH_64_BITS
-#define TPE long long int
-	long long int dummy;
-#else
-        int dummy;
-#define TPE int
-#endif
-
-        dummy=(TPE)user_data;
-
-        action=(gui_act) dummy;
-        on_action(action);
-}
 //
 // One of the button of the main dialog was pressed
 // Retrieve also the associated filter and handle
@@ -168,7 +150,7 @@ void on_action (gui_act action)
     action_parameter = 0;
     if (nb_active_filter > 1)
         if (getSelectionNumber(nb_active_filter - 1,
-                                WID(treeview0),
+                                WID(treeviewActive),
                                 stores[0],
                                 &action_parameter))
             action_parameter++;
@@ -193,31 +175,31 @@ void on_action (gui_act action)
         videofilters[nb_active_filter].conf = coup;
         nb_active_filter++;
         updateFilterList ();
-        setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], nb_active_filter-2);
+        setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], nb_active_filter-2);
         break;
 
     case A_VCD:
         setVCD ();
         updateFilterList ();
-        setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], nb_active_filter-2);
+        setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], nb_active_filter-2);
         break;
 
     case A_SVCD:
         setSVCD ();
         updateFilterList ();
-        setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], nb_active_filter-2);
+        setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], nb_active_filter-2);
         break;
 
     case A_DVD:
         setDVD ();
         updateFilterList ();
-        setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], nb_active_filter-2);
+        setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], nb_active_filter-2);
         break;
 
     case A_HALFD1:
         setHalfD1 ();
         updateFilterList ();
-        setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], nb_active_filter-2);
+        setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], nb_active_filter-2);
         break;
 
     default:
@@ -232,7 +214,7 @@ void on_action (gui_act action)
         videofilters[action_parameter].conf = couple;
         getFirstVideoFilter ();
         updateFilterList ();
-        setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], action_parameter-1);
+        setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], action_parameter-1);
         break;
 
     case A_PARTIAL:
@@ -240,7 +222,7 @@ void on_action (gui_act action)
         AVDMGenericVideoStream *replace;
         CONFcouple *conf;
         conf = videofilters[action_parameter].conf;
-        if (videofilters[action_parameter].tag == VF_PARTIAL)	// cannot recurse
+        if (videofilters[action_parameter].tag == VF_PARTIAL_FILTER)	// cannot recurse
         {
             GUI_Error_HIG (QT_TR_NOOP("The filter is already partial"), NULL);
             break;
@@ -257,10 +239,10 @@ void on_action (gui_act action)
 			videofilters[action_parameter].filter = replace;
 			replace->getCoupledConf (&conf);
 			videofilters[action_parameter].conf = conf;
-			videofilters[action_parameter].tag = VF_PARTIAL;
+			videofilters[action_parameter].tag = VF_PARTIAL_FILTER;
 			getFirstVideoFilter ();
 			updateFilterList ();
-			setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], action_parameter-1);
+			setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], action_parameter-1);
         }
         else delete replace;
         break;
@@ -277,7 +259,7 @@ void on_action (gui_act action)
         // select action_parameter -1
         updateFilterList ();
         setSelectionNumber (nb_active_filter - 1,
-			      WID(treeview0),
+			      WID(treeviewActive),
 			      stores[0], action_parameter - 2);
         break;
 
@@ -293,7 +275,7 @@ void on_action (gui_act action)
             getFirstVideoFilter ();
             updateFilterList ();
             setSelectionNumber (nb_active_filter - 1,
-			      WID(treeview0),
+			      WID(treeviewActive),
 			      stores[0], action_parameter);
         }
         break;
@@ -322,8 +304,8 @@ void on_action (gui_act action)
 		videofilters[nb_active_filter - 1].filter = NULL;
 		nb_active_filter--;
         updateFilterList ();
-        if(!setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], action_parameter-1))
-            setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], action_parameter-2);
+        if(!setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], action_parameter-1))
+            setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], action_parameter-2);
 		break;
 
     case A_DONE:
@@ -345,7 +327,7 @@ void on_action (gui_act action)
         GUI_FileSelRead (QT_TR_NOOP("Load set of filters"), filterLoad);
 #endif
         updateFilterList ();
-        setSelectionNumber(nb_active_filter-1, WID(treeview0), stores[0], 0);
+        setSelectionNumber(nb_active_filter-1, WID(treeviewActive), stores[0], 0);
         break;
     case A_CLOSE:
         //gtk_widget_destroy(dialog);
@@ -372,143 +354,186 @@ void on_action (gui_act action)
     } //end of switch
 }
 /*
- 	Pop-up a list of all available filters
-	Return the tag identifying the filter selected
+ 	\fn getFilterFromSelection
+	\brief returns the tag of the selected filter
 */
-VF_FILTERS
-getFilterFromSelection (void)
+VF_FILTERS getFilterFromSelection (void)
 {
-    uint32_t sel = 0;
+    uint32_t sel = 0, category = 0;
 	uint8_t ret = 0;
     VF_FILTERS tag = VF_INVALID;
     // 1- identify the current tab/treeview we are in
-    int page = gtk_notebook_get_current_page(GTK_NOTEBOOK(lookup_widget(dialog,"notebook1")));
+    ret = getSelectionNumber (VF_MAX+1, treeCategories, storeCategories, &category);
     // then get the selection
-    page++;
-    if ((ret = getSelectionNumber (max, trees[page], stores[page], &sel)))
-	{
-        tag = allfilters[sel+startFilter[page]].tag;
-	}
+    category++;
+    if (ret == 1)
+    {
+        if ((ret = getSelectionNumber (max, treeAvailable, stores[category], &sel)))
+        {
+            tag = filterCategories[category-1][sel]->tag;
+        }
+    }
     return tag;
 }
 
+/**
+ * 	\fn createTree
+ *  \brief Set up a TreeView for the Available and Active Filters list
+ */
+GtkWidget *createTree (const gchar *ref)
+{
+	GtkWidget *tree = lookup_widget (dialog, ref); 
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
+	GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes ("", renderer, "markup", (GdkModifierType) 0, NULL);
+	gtk_widget_set_size_request (tree, tree_width, -1);
+	g_object_set (renderer, "ypad", 6, NULL);
+	g_object_set (renderer, "wrap-width", tree_width-8, NULL);
+	g_object_set (renderer, "wrap-mode", PANGO_WRAP_WORD_CHAR, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(tree), column);
+	g_signal_connect (G_OBJECT(tree), "size-allocate", G_CALLBACK(on_tree_size_allocate), renderer);
+	return tree;
+}
+
+/**
+ * 	\fn createFilterDialog
+ *  \brief Create the dialog including list of all filters available on the left.
+ * 
+ */
 GtkWidget *
 createFilterDialog (void)
 {
-    dialog = create_dialog1();
+	dialog = create_dialog1();
+	GtkTreeIter iter;
 
-    //connect toolbar
-#define CALLME_TOOLBAR(x,y) gtk_signal_connect(GTK_OBJECT(WID(x)),"clicked",  GTK_SIGNAL_FUNC(wrapToolButton), (void *) y);
-#define CALLME(x,y) gtk_dialog_add_action_widget (GTK_DIALOG (dialog), WID(x), y)
+	//Connect buttons from the Available and Active Filters list
+	#define CONNECT(button, action) g_signal_connect (G_OBJECT(WID(button)), "clicked", G_CALLBACK(button_clicked), (void*)action);
 
-	//CALLME (toolbuttonAdd, A_ADD);
-        // Each of these triggers the following message:
-        // Gtk-CRITICAL **: gtk_box_pack_end: assertion `child->parent == NULL' failed
-        CALLME (buttonRemove,		A_REMOVE);
-        CALLME (buttonProperties,	A_CONFIGURE);
-        CALLME (buttonUp, 		A_UP);
-        CALLME (buttonDown, 		A_DOWN);
-        CALLME (buttonPreview, 		A_PREVIEW);
-        CALLME (buttonPartial, 		A_PARTIAL);
-        CALLME (buttonAdd, 		A_ADD);
-        
-        CALLME_TOOLBAR (toolbuttonHalfD1, 	A_HALFD1);
-        CALLME_TOOLBAR (toolbuttonScript, 	A_SCRIPT);
-        CALLME_TOOLBAR (toolbuttonVCD, 		A_VCD);
-        CALLME_TOOLBAR (toolbuttonSVCD, 	A_SVCD);
-        CALLME_TOOLBAR (toolbuttonDVD, 		A_DVD);
-        CALLME_TOOLBAR (toolbuttonSave, 	A_SAVE);
-        CALLME_TOOLBAR (toolbuttonScript, 	A_SAVE);
-        CALLME_TOOLBAR (toolbuttonOpen, 	A_LOAD);
-        
+	CONNECT (buttonAdd, A_ADD)
+	CONNECT (buttonRemove, A_REMOVE)
+	CONNECT (buttonProperties, A_CONFIGURE)
+	CONNECT (buttonUp, A_UP)
+	CONNECT (buttonDown, A_DOWN)
+	CONNECT (buttonPreview, A_PREVIEW)
+	CONNECT (buttonPartial, A_PARTIAL)
+	CONNECT (buttonVCDRes, A_VCD)
+	CONNECT (buttonSVCDRes, A_SVCD)
+	CONNECT (buttonHalfD1Res, A_HALFD1)
+	CONNECT (buttonDVDRes, A_DVD)
+	CONNECT (buttonOpen, A_LOAD)
+	CONNECT (buttonSave, A_SAVE)
 
-    //create treeviews
-    trees[0]=lookup_widget(dialog,"treeview0");
-    stores[0]=gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_POINTER);
-    #define LOOK(x) {trees[x]=lookup_widget(dialog,"treeview"#x);\
-                    stores[x]=gtk_list_store_new (1, G_TYPE_STRING);}
-    LOOK(1);
-    LOOK(2);
-    LOOK(3);
-    LOOK(4);
-    LOOK(5);
-    LOOK(6);
-    LOOK(7);
-    LOOK(8);
+	//Create TreeView with the filter categories
+	enum
+	{
+		ICON_COLUMN,
+		CATEGORY_COLUMN,
+		N_COLUMNS
+	};
 
-    //load stores with filter names, get start filter for each page
-    char *str=NULL;
-    GtkTreeIter iter;
-    int current_tree=0;
-    for (uint32_t i = 0; i < allfilters.size(); i++)
-    {
-        if (allfilters[i].viewable==1)
-        {
-		
-		 str = g_strconcat(
-				 "<span weight=\"bold\">", allfilters[i].name, "</span>\n",
-                 		//	"", allfilters[i].description, "", NULL);
-                 			"<span size=\"smaller\">", allfilters[i].description, "</span>", NULL);
-				
-            gtk_list_store_append (stores[current_tree], &iter);
-            gtk_list_store_set (stores[current_tree], &iter, 0, str ,-1);
-            g_free(str);
-            max++;
-        }else
-        {
-                current_tree++;
-                if(current_tree>=NB_TREE) break;
-                startFilter[current_tree]=i+1;
-        }
-    }
+	storeCategories = gtk_list_store_new (N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+	GdkPixbuf *pb;
 
-    //setup treeviews
-    for(int i=0;i<NB_TREE;i++)
-    {
-        renderers[i] = gtk_cell_renderer_text_new();
-   		columns[i] = gtk_tree_view_column_new_with_attributes (
-                            "",
-                            renderers[i],
-                            "markup", (GdkModifierType) 0,
-                            NULL);
-		gtk_cell_renderer_text_set_fixed_height_from_font
-			(GTK_CELL_RENDERER_TEXT(renderers[i]), 3);
-        g_object_set(renderers[i], "wrap-width", 0, NULL);
-        gtk_tree_view_append_column(GTK_TREE_VIEW (trees[i]), columns[i]);
-        gtk_tree_view_set_model(GTK_TREE_VIEW(trees[i]),GTK_TREE_MODEL (stores[i]));
+	#define ADD_CATEGORY(icon, category) \
+		gtk_list_store_append (storeCategories, &iter); \
+		pb = create_pixbuf (#icon); \
+		gtk_list_store_set (storeCategories, &iter, ICON_COLUMN, pb, CATEGORY_COLUMN, QT_TR_NOOP(#category), -1);
 
-		// Add double click, 0 is active filter tree
-        if(i)
-        	g_signal_connect (G_OBJECT(trees[i]),
-                      "row-activated",
-                      G_CALLBACK(on_action_double_click),
-                      (void *) dialog);
-  		else
-  		{
-            gtk_tree_view_set_reorderable(GTK_TREE_VIEW(trees[i]), true);
-  			g_signal_connect(G_OBJECT(WID(treeview0)),
-  						"row-activated",
-        				G_CALLBACK(on_action_double_click_1),
-        				(void *)NULL);
-   			row_inserted_id=g_signal_connect(G_OBJECT(stores[i]),
-  						"row-inserted",
-        				G_CALLBACK(on_treeview0_row_inserted),
-        				(void *)NULL);
-   			row_deleted_id=g_signal_connect(G_OBJECT(stores[i]),
-  						"row-deleted",
-        				G_CALLBACK(on_treeview0_row_deleted),
-        				(void *)NULL);
-  		}
-        g_signal_connect(G_OBJECT(trees[i]),
-                      "size-allocate",
-                      G_CALLBACK(on_treeview1_size_allocate),
-                      renderers[i]);
-    }
+	ADD_CATEGORY (1.png, Transform)
+	ADD_CATEGORY (2.png, Interlacing)
+	ADD_CATEGORY (4.png, Colors)
+	ADD_CATEGORY (5.png, Noise)
+	ADD_CATEGORY (3.png, Sharpness)
+	ADD_CATEGORY (7.png, Subtitles)
+	ADD_CATEGORY (6.png, Miscellaneous)
+	ADD_CATEGORY (film1.xpm, External)
+
+	treeCategories = lookup_widget (dialog, "mainTree");
+	gtk_tree_view_set_model (GTK_TREE_VIEW(treeCategories), GTK_TREE_MODEL(storeCategories));
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(treeCategories), FALSE);
+
+	GtkCellRenderer *renderer;
+	renderer = gtk_cell_renderer_pixbuf_new();
+
+	GtkTreeViewColumn *column;
+	column = gtk_tree_view_column_new ();
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeCategories), column);
+	gtk_tree_view_column_pack_start (column, renderer, TRUE);
+	gtk_tree_view_column_add_attribute (column, renderer, "pixbuf", ICON_COLUMN);
+
+	column = gtk_tree_view_column_new ();
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeCategories), column);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (column, renderer, TRUE);
+	gtk_tree_view_column_add_attribute (column, renderer, "text", CATEGORY_COLUMN);
+	g_object_set (renderer, "ypad", 6, NULL);
+
+	//Create ListStores with filters, store zero is the Active Filters list
+	stores[0]=gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_POINTER);
+
+	#define CREATE_STORE(x) stores[x] = gtk_list_store_new (1, G_TYPE_STRING);
+
+	CREATE_STORE (1)
+	CREATE_STORE (2)
+	CREATE_STORE (3)
+	CREATE_STORE (4)
+	CREATE_STORE (5)
+	CREATE_STORE (6)
+	CREATE_STORE (7)
+	CREATE_STORE (8)
+
+	//load stores with filter names, get start filter for each page
+	char *str=NULL;
+
+	// Dispatch each category to the matching tree
+	for(int current_tree=0;current_tree< VF_MAX;current_tree++)
+	{
+		std::vector <FilterDescriptor *> vec=filterCategories[current_tree];
+		for (uint32_t i = 0; i < vec.size(); i++)
+		{
+			str = g_strconcat(
+				"<span weight=\"bold\">", vec[i]->name, "</span>\n",
+				"<span size=\"smaller\">", vec[i]->description, "</span>", NULL);
+
+			gtk_list_store_append (stores[current_tree+1], &iter);
+			gtk_list_store_set (stores[current_tree+1], &iter, 0, str ,-1);
+			g_free(str);
+			max++;
+		}
+	}
+
+	//Create TreeViews with available and active filters
+	treeAvailable = createTree ("treeviewAvailable");
+	g_signal_connect (G_OBJECT(treeAvailable), "row-activated", G_CALLBACK(on_action_double_click), (void *) dialog);
+	g_signal_connect (G_OBJECT(treeCategories), "cursor-changed", G_CALLBACK(on_action_change_category), NULL);
+
+	treeActive = createTree ("treeviewActive");
+	gtk_tree_view_set_model (GTK_TREE_VIEW(treeActive), GTK_TREE_MODEL(stores[0]));
+	gtk_tree_view_set_reorderable (GTK_TREE_VIEW(treeActive), true);
+	g_signal_connect (G_OBJECT(treeActive), 
+		"row-activated", G_CALLBACK(on_action_double_click_1), 
+		(void *)NULL);
+	row_inserted_id = g_signal_connect (G_OBJECT(stores[0]), 
+		"row-inserted", 
+		G_CALLBACK(on_treeActive_row_inserted), 
+		(void *)NULL);
+	row_deleted_id = g_signal_connect (G_OBJECT(stores[0]), 
+		"row-deleted", 
+		G_CALLBACK(on_treeActive_row_deleted), 
+		(void *)NULL);
+
+	//Select the first category in treeCategories and show its filters in treeAvailable
+	gtk_widget_grab_focus (treeCategories);
+	GtkTreePath *gp = gtk_tree_path_new_first ();
+	gtk_tree_view_set_cursor (GTK_TREE_VIEW(treeCategories), gp, NULL, TRUE);
     return dialog;
 }
 
-void
-updateFilterList (void)
+/**
+ * 	\fn updateFilterList
+ *  \brief Update the list of activated filters
+ */
+void updateFilterList (void)
 {
     g_signal_handler_block(stores[0], row_inserted_id);
     g_signal_handler_block(stores[0], row_deleted_id);
@@ -575,6 +600,17 @@ on_action_double_click (GtkButton * button, gpointer user_data)
     on_action(A_ADD);
 }
 
+void
+on_action_change_category (GtkWidget * tree, gpointer user_data)
+{
+	GtkAdjustment *adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW(WID(scrolledwindowAvailable)));
+	gtk_adjustment_set_value (adj, 0);
+
+	uint32_t number = 0;
+	if (getSelectionNumber (VF_MAX+1, tree, storeCategories, &number))
+		gtk_tree_view_set_model (GTK_TREE_VIEW(treeAvailable), GTK_TREE_MODEL(stores[number+1]));
+}
+
 void
 on_action_double_click_1 (GtkButton * button, gpointer user_data)
 {
@@ -582,15 +618,13 @@ on_action_double_click_1 (GtkButton * button, gpointer user_data)
 }
 
 void
-on_treeview1_size_allocate(GtkWidget *widget, GtkAllocation *allocation, GtkCellRenderer *cell)
+on_tree_size_allocate(GtkWidget *widget, GtkAllocation *allocation, GtkCellRenderer *cell)
 {
-    g_object_set(cell,
-              "wrap-width", allocation->width-8,
-              NULL);
+	g_object_set (cell, "wrap-width", allocation->width-8, NULL);
 }
 
 void
-on_treeview0_row_deleted(GtkTreeModel *treemodel, GtkTreePath *arg1, gpointer user_data)
+on_treeActive_row_deleted(GtkTreeModel *treemodel, GtkTreePath *arg1, gpointer user_data)
 {
     GtkTreeIter iter;
     VF_FILTERS				tag;
@@ -617,10 +651,24 @@ on_treeview0_row_deleted(GtkTreeModel *treemodel, GtkTreePath *arg1, gpointer us
     //on_action(A_REORDERED);
 }
 void
-on_treeview0_row_inserted(GtkTreeModel *treemodel, GtkTreePath *arg1, GtkTreeIter *arg2, gpointer user_data)
+on_treeActive_row_inserted(GtkTreeModel *treemodel, GtkTreePath *arg1, GtkTreeIter *arg2, gpointer user_data)
 {
 
 
 }
 
+static void button_clicked(GtkWidget * wid, gpointer user_data)
+{
+	gui_act action;
+#ifdef ADM_CPU_64BIT
+#define TPE long long int
+	long long int dummy;
+#else
+	int dummy;
+#define TPE int
 #endif
+	dummy=(TPE)user_data;
+	action=(gui_act) dummy;
+
+	on_action(action);
+}
