@@ -20,33 +20,27 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "default.h"
+#include "ADM_default.h"
+
 #include "ADM_assert.h"
 
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_video/ADM_vidCNR2_param.h"
-#include "ADM_video/ADM_vidColorYuv_param.h"
+#include "ADM_videoFilter.h"
+
+
 #include "ADM_video/ADM_vidPartial_param.h"
-#include "ADM_video/ADM_vidEqualizer.h"
-#include "ADM_video/ADM_vidMPdelogo.h"
+
 
-#include "ADM_videoFilter/ADM_vidAnimated_param.h"
-#include "ADM_videoFilter/ADM_vidASharp_param.h"
-#include "ADM_videoFilter/ADM_vidChromaShift_param.h"
-#include "ADM_videoFilter/ADM_vidContrast.h"
-#include "ADM_videoFilter/ADM_vidEq2.h"
-#include "ADM_videoFilter/ADM_vidHue.h"
 #include "ADM_videoFilter/ADM_vobsubinfo.h"
 #include "ADM_videoFilter/ADM_vidVobSub.h"
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_audiofilter/audioencoder.h"
+#include "ADM_coreAudio/include/audioencoder.h"
 #include "ADM_lavcodec.h"
 #include "ADM_codecs/ADM_ffmpegConfig.h"
 
 #include "ADM_ocr/ADM_ocr.h"
 #include "ADM_ocr/ADM_ocrInternal.h"
-
+#include "ADM_userInterfaces/ADM_render/GUI_renderInternal.h"
 extern int global_argc;
 extern char **global_argv;
 extern void initTranslator(void);
@@ -54,8 +48,8 @@ extern int automation(void);
 
 int SliderIsShifted = 0;
 
-int DIA_coloryuv(COLOR_YUV_PARAM *param) {return 0;}
-int DIA_getCropParams(const char *name,CROP_PARAMS *param,AVDMGenericVideoStream *in) {return 0;}
+
+
 
 #ifdef USE_XX_XVID 
 #include "xvid.h"
@@ -63,21 +57,15 @@ int  DIA_getXvidCompressParams(COMPRESSION_MODE * mode, uint32_t * qz,
 		      uint32_t * br,uint32_t *fsize,xvidEncParam *param) {return 0;}
 #endif
 
-uint8_t DIA_animated(ANIMATED_PARAM *param) {return 0;}
-uint8_t DIA_cnr2(CNR2Param *param) {return 0;}
-uint8_t DIA_getASharp(ASHARP_PARAM *param, AVDMGenericVideoStream *in) {return 0;}
-uint8_t DIA_getEQ2Param(Eq2_Param *param, AVDMGenericVideoStream *in) {return 0;}
-uint8_t DIA_getEqualizer(EqualizerParam *param, ADMImage *image) {return 0;}
-uint8_t DIA_getEqualizer(EqualizerParam *param, AVDMGenericVideoStream *in) {return 0;}
-uint8_t DIA_getHue(Hue_Param *param, AVDMGenericVideoStream *in) {return 0;}
-uint8_t DIA_getMPdelogo(MPDELOGO_PARAM *param,AVDMGenericVideoStream *in) {return 0;}
+
+
+
+
 uint8_t DIA_getPartial(PARTIAL_CONFIG *param,AVDMGenericVideoStream *son,AVDMGenericVideoStream *previous) {return 0;}
 uint8_t DIA_pipe(char **cmd,char **param) {return 0;}
 uint8_t DIA_vobsub(vobSubParam *param) {return 0;}
-uint8_t DIA_x264(COMPRES_PARAMS *config) {return 0;}
 uint8_t DIA_XVCDParam(char *title,COMPRESSION_MODE * mode, uint32_t * qz,
 		   				   uint32_t * br,uint32_t *fsize,FFcodecSetting *conf) {return 0;}
-uint8_t DIA_xvid4(COMPRES_PARAMS *incoming) {return 0;}
 uint8_t DIA_quota(char *) {return 0;}
 const char * GUI_getCustomScript(uint32_t nb) {return 0;}
 uint8_t DIA_RecentFiles( char **name ) {return 0;}
@@ -85,7 +73,6 @@ uint8_t DIA_about( void ) {return 0;}
 void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate ) {}
 void DIA_properties(void) {}
 int GUI_handleVFilter (void) {return 0;}
-uint8_t initFileSelector(void) {return 0;}
 uint8_t initGUI(void) {return 1;}
 void destroyGUI(void) {}
 uint8_t DIA_job(uint32_t nb,char **name) {return 0;}
@@ -95,14 +82,10 @@ uint8_t DIA_d3d(double *luma,double *chroma,double *temporal) {return 0;}
 uint8_t DIA_kerneldeint(uint32_t *order, uint32_t *threshold, uint32_t *sharp, 
                           uint32_t *twoway, uint32_t *map) {return 0;}
 uint8_t DIA_4entries(char *title,uint32_t *left,uint32_t *right,uint32_t *top,uint32_t *bottom) {return 0;}
-uint8_t DIA_videoCodec (SelectCodecType * codec) {return 0;}
-uint8_t DIA_getChromaShift( AVDMGenericVideoStream *instream,CHROMASHIFT_PARAM *param ) {return 0;}
-uint8_t DIA_contrast(AVDMGenericVideoStream *astream,CONTRAST_PARAM *param) {return 0;}
-uint8_t DIA_audioCodec( AUDIOENCODER *codec ) {return 0;}
+uint8_t DIA_videoCodec(int *codecIndex) {return 0;}
+uint8_t DIA_audioCodec( int *codec ) {return 0;}
 uint8_t DIA_dnr(uint32_t *llock,uint32_t *lthresh, uint32_t *clock,
 			uint32_t *cthresh, uint32_t *scene) {return 0;}
-int DIA_srtPos(AVDMGenericVideoStream *source,uint32_t *size,uint32_t *position) {return 0;}
-int DIA_colorSel(uint8_t *r, uint8_t *g, uint8_t *b) {return 0;}			
 uint8_t DIA_glyphEdit(void) {return 0;}
 struct THRESHOLD_PARAM;
 struct ADMVideoThreshold;
@@ -139,14 +122,27 @@ uint8_t ADM_ocrUiEnd(void *d) {	return 0;}
 void *ADM_ocrUiSetup(void) {return 0;}
 uint8_t ADM_ocrSetRedrawSize(void *ui,uint32_t w,uint32_t h) {return 0;}
 ReplyType glyphToText(admGlyph *glyph,admGlyph *head,char *decodedString) {return ReplyOk;}
+extern void UI_purge(void);
+extern ADM_RENDER_TYPE UI_getPreferredRender(void);
 
+static const UI_FUNCTIONS_T UI_Hooks=
+    {
+        ADM_RENDER_API_VERSION_NUMBER,
+        UI_purge,
+        UI_getWindowInfo,
+        UI_updateDrawWindowSize,
+        UI_rgbDraw,
+        UI_getDrawWidget,
+        UI_getPreferredRender
+        
+    };
 int UI_Init(int nargc, char **nargv)
 {
 	initTranslator();
 
 	global_argc = nargc;
 	global_argv = nargv;
-
+        ADM_renderLibInit(&UI_Hooks);
 	return 0;
 }
 
